@@ -3,13 +3,14 @@
 # Protocol) packets.
 
 package NetPacket::IGMP;
+BEGIN {
+  $NetPacket::IGMP::VERSION = '0.43.1';
+}
 
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-our $VERSION = '0.43.0';
-
 BEGIN {
     @ISA = qw(Exporter NetPacket);
 
@@ -145,8 +146,11 @@ __END__
 
 =head1 NAME
 
-C<NetPacket::IGMP> - Assemble and disassemble IGMP (Internet Group
-Mangement Protocol) packets. 
+C<NetPacket::IGMP> - Assemble and disassemble IGMP (Internet Group Mangement Protocol) packets. 
+
+=head1 VERSION
+
+version 0.43.1
 
 =head1 SYNOPSIS
 
@@ -324,4 +328,4 @@ Tim Potter E<lt>tpot@samba.orgE<gt>
 
 =cut
 
-# any real autoloaded methods go after this line
+# any real autoloaded methods go after this line
\ No newline at end of file
