@@ -3,14 +3,15 @@
 # packets. 
 
 package NetPacket::UDP;
+BEGIN {
+  $NetPacket::UDP::VERSION = '0.43.1';
+}
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
 use NetPacket::IP;
 
-our $VERSION = '0.43.0';
-
 BEGIN {
     @ISA = qw(Exporter NetPacket);
 
@@ -142,8 +143,11 @@ __END__
 
 =head1 NAME
 
-C<NetPacket::UDP> - Assemble and disassemble UDP (User Datagram
-Protocol) packets.
+C<NetPacket::UDP> - Assemble and disassemble UDP (User Datagram Protocol) packets.
+
+=head1 VERSION
+
+version 0.43.1
 
 =head1 SYNOPSIS
 
@@ -335,4 +339,4 @@ Stephanie Wehner E<lt>atrak@itsx.comE<gt>
 
 Yanick Champoux <yanick@cpan.org>
 
-=cut
+=cut
\ No newline at end of file
